ImageProcessing class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
extractImage(
{required File? imageFile, required String? networkImage, required double dragItemSize, required Offset initialDragItemPos, required ValueChanged< File> onExtractedImage}) → Future<void> -
getFromFile(
File file) → Future< File?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processImageFromFile(
File file, Size containerSize, Offset offset) → Future< File?> -
processImageFromNetwork(
String imageUrl, Size containerSize, Offset offset) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
unit8ListToFile(
) → Future< File>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited